@@ -170,9 +170,9 @@ class Atom:
                                     '../parameters/atomic_form_factors/{:s}'.format(sub_path))
         try:
             f = np.genfromtxt(filename, skip_header=0)
-        except Exception as e:
-            print('File {:s} not found!'.format(filename))
-            print(e)
+        except OSError:
+            print('Atomic form factor file {:s} not found!'.format(filename))
+            raise
 
         return f
 
